from pkg_resources import resource_filename
from typing import List
from pathlib import Path


def get_data(folder: str, filename: str) -> List[str]:
    words = []
    data_path = Path(resource_filename('randword', 'data'))
    filepath = data_path / folder / f'{filename}.txt'

    with open(filepath, 'r') as pos_file:
        pos_words = pos_file.readlines()
        words.extend(pos_words)

    return [word.rstrip() for word in words]



from random import choice, randrange, getrandbits
from time import sleep

from .utilities import get_data


def magic_8ball() -> None:
    answers = get_data('other', 'magic_8ball_answers')

    def main() -> None:
        input('Ask me a question:\n  ')

        print('Thinking...')
        sleep(randrange(0, 3))

        print(f'  {choice(answers)}\n')

    while True:
        main()
        repeat = input('Would you like to ask another question? [Y/N] ')
        if repeat.upper() != 'Y':
            print('Come back if you have questions.')
            break


def flip_coin() -> bool:
    return bool(getrandbits(1))


if __name__ == '__main__':
    print(flip_coin())



from random import choice, sample
from typing import Optional, List, Union

from .utilities import get_data


def name(count: Optional[int] = None,
         gender: Optional[str] = None) -> Union[str, List[str]]:
    '''
    Returns a random first name or a list of them

    Args:
        count (int, optional): The number of names to be
            generated. Defaults to `None`
        gender (str, optional): Specifies the name of which gender
            will be generated. Defaults to `None`

    Returns:
        str: A random first name if `count` is `None`
        list of str: A list of random first names
            if `count` is not `None`
    '''
    if gender == 'm':
        names = get_data('names', 'male_names')
    elif gender == 'f':
        names = get_data('names', 'female_names')
    else:
        male_names = get_data('names', 'male_names')
        female_names = get_data('names', 'female_names')
        names = male_names + female_names

    if count:
        return sample(names, count)
    else:
        return choice(names)


def surname(count: Optional[int] = None) -> Union[str, List[str]]:
    '''
    Returns a random surname or a list of them

    Args:
        count (int, optional): The number of surnames to be
            generated. Defaults to `None`

    Returns:
        str: A random surname if `count` is `None`
        list of str: A list of surnames if `count` is not `None`
    '''
    surnames = get_data('names', 'surnames')

    if count:
        return sample(surnames, count)
    else:
        return choice(surnames)


def fullname(count: Optional[int] = None,
             gender: Optional[str] = None) -> Union[str, List[str]]:
    '''
    Returns a random fullname or a list of them

    Args:
        count (int, optional): The number of fullnames to be
            generated. Defaults to `None`
        gender (str): Specifies the fullname of which gender
            will be generated. Defaults to `None`

    Returns:
        str: A random fullname if `count` is `None`
        list of str: A list of random fullnames
            if `count` is not `None`
    '''
    if gender == 'm':
        names = get_data('names', 'male_names')
    elif gender == 'f':
        names = get_data('names', 'female_names')
    else:
        male_names = get_data('names', 'male_names')
        female_names = get_data('names', 'female_names')
        names = male_names + female_names

    surnames = get_data('names', 'surnames')

    if count:
        fullnames = []
        random_names = sample(names, count)
        random_surnames = sample(surnames, count)

        for name, surname in zip(random_names, random_surnames):
            fullnames.append(f'{name} {surname}')

        return fullnames
    else:
        return f'{choice(names)} {choice(surnames)}'


if __name__ == '__main__':
    print(name())
    print(surname())
    print(fullname())



'''
A module that provides the generation of various information.
'''

from .rand_word import PARTS_OF_SPEECH, word
from .rand_name import name, surname, fullname
from .rand_place import country, city
from .rand_letter import sequence, letter, digit
from .rand_other import magic_8ball, flip_coin



from setuptools import setup


with open('README.md', 'r') as readme_file:
    long_description = readme_file.read()
VERSION = '2.6.5'


setup(
    name='randword',
    description='A Python package for generation random English words',
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords=[
        'python', 'package', 'python-package', 'random',
        'word', 'words', 'generator', 'generation',
        'random-word', 'random-words', 'random-word-generator',
        'random-word-generation', 'english',
        'english-word', 'english-words'
    ],
    version=VERSION,

    author='Artyom Bezmenov (8nhuman)',
    author_email='artem.bezmenov02@gmail.com',
    license='MIT',

    packages=['randword'],
    include_package_data=True,

    project_urls={
        'Bug Tracker': 'https://github.com/8nhuman8/randword/issues',
        'Source Code': 'https://github.com/8nhuman8/randword',
        'Download': f'https://github.com/8nhuman8/randword/archive/{VERSION}.tar.gz',
        'Homepage': 'https://github.com/8nhuman8/randword'
    },

    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Development Status :: 5 - Production/Stable',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent'
    ]
)
